@@ -3,7 +3,7 @@ package Mojo::Transaction::HTTP::Role::Mechanize;
 use Mojo::Base -role;
 use Mojo::UserAgent::Transactor;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 requires qw{error};
 
@@ -19,12 +19,14 @@ sub submit {
   # compose ...
   $form->with_roles('Mojo::DOM::Role::Form')
     unless Role::Tiny::does_role($form, 'Mojo::DOM::Role::Form');
+  # now there is a form, rely on _form_default_submit() if we relied on $any b4.
+  $selector = undef if $any eq $selector;
   return unless (my ($method, $target, $type) =
     $form->target($selector));
   $target = $self->req->url->new($target);
   $target = $target->to_abs($self->req->url) unless $target->is_abs;
   # values from form
-  my $state = $form->val;
+  my $state = $form->val($selector);
   # merge in new values of form elements
   my @keys = grep { exists $overlay->{$_} } keys %$state;
   @$state{@keys} = @$overlay{@keys};
@@ -43,7 +45,18 @@ sub submit {
 =begin html
 
 <a href="https://travis-ci.com/kiwiroy/mojo-transaction-http-role-mechanize">
-  <img src="https://travis-ci.com/kiwiroy/mojo-transaction-http-role-mechanize.svg?branch=master">
+  <img alt="Travis Build Status"
+       src="https://travis-ci.com/kiwiroy/mojo-transaction-http-role-mechanize.svg?branch=master" />
+</a>
+
+<a href="https://kritika.io/users/kiwiroy/repos/7509235145731088/heads/master/">
+  <img alt="Kritika Analysis Status"
+       src="https://kritika.io/users/kiwiroy/repos/7509235145731088/heads/master/status.svg?type=score%2Bcoverage%2Bdeps" />
+</a>
+
+<a href="https://coveralls.io/github/kiwiroy/mojo-transaction-http-role-mechanize?branch=master">
+  <img alt="Coverage Status"
+       src="https://coveralls.io/repos/github/kiwiroy/mojo-transaction-http-role-mechanize/badge.svg?branch=master" />
 </a>
 
 =end html
@@ -81,6 +94,10 @@ C<$id> and merged values.
 
 kiwiroy - Roy Storey <kiwiroy@cpan.org>
 
+=head1 CONTRIBUTORS
+
+tekki - Rolf Stöckli <tekki@cpan.org>
+
 =head1 LICENSE
 
 This library is free software and may be distributed under the same terms as
